@@ -27,6 +27,7 @@
 #include "ephy-synchronizable-manager.h"
 
 #include <glib/gi18n.h>
+#include <inttypes.h>
 #include <stdio.h>
 
 const SecretSchema *
@@ -188,7 +189,7 @@ get_attributes_table (const char *id,
                       const char *username,
                       const char *username_field,
                       const char *password_field,
-                      double      server_time_modified)
+                      gint64      server_time_modified)
 {
   GHashTable *attributes = secret_attributes_build (EPHY_FORM_PASSWORD_SCHEMA, NULL);
 
@@ -219,7 +220,7 @@ get_attributes_table (const char *id,
   if (server_time_modified >= 0)
     g_hash_table_insert (attributes,
                          g_strdup (SERVER_TIME_MODIFIED_KEY),
-                         g_strdup_printf ("%.2lf", server_time_modified));
+                         g_strdup_printf ("%"PRId64, server_time_modified));
 
   return attributes;
 }
@@ -391,7 +392,7 @@ ephy_password_manager_store_record (EphyPasswordManager *self,
   const char *username_field;
   const char *password_field;
   char *label;
-  double modified;
+  gint64 modified;
 
   g_assert (EPHY_IS_PASSWORD_MANAGER (self));
   g_assert (EPHY_IS_PASSWORD_RECORD (record));
@@ -529,7 +530,7 @@ secret_service_search_cb (SecretService  *service,
     const char *password_field = g_hash_table_lookup (attributes, PASSWORD_FIELD_KEY);
     const char *timestamp = g_hash_table_lookup (attributes, SERVER_TIME_MODIFIED_KEY);
     const char *password = secret_value_get (value, NULL);
-    double server_time_modified;
+    gint64 server_time_modified;
     EphyPasswordRecord *record;
 
     LOG ("Found password record for (%s, %s, %s, %s, %s)",
@@ -545,7 +546,7 @@ secret_service_search_cb (SecretService  *service,
                                        username_field, password_field,
                                        secret_item_get_created (item) * 1000,
                                        secret_item_get_modified (item) * 1000);
-    sscanf (timestamp, "%lf", &server_time_modified);
+    server_time_modified = g_ascii_strtod (timestamp, NULL);
     ephy_synchronizable_set_server_time_modified (EPHY_SYNCHRONIZABLE (record),
                                                   server_time_modified);
     records = g_list_prepend (records, record);
@@ -741,7 +742,7 @@ synchronizable_manager_set_is_initial_sync (EphySynchronizableManager *manager,
   ephy_sync_utils_set_passwords_sync_is_initial (is_initial);
 }
 
-static double
+static gint64
 synchronizable_manager_get_sync_time (EphySynchronizableManager *manager)
 {
   return ephy_sync_utils_get_passwords_sync_time ();
@@ -749,7 +750,7 @@ synchronizable_manager_get_sync_time (EphySynchronizableManager *manager)
 
 static void
 synchronizable_manager_set_sync_time (EphySynchronizableManager *manager,
-                                      double                     sync_time)
+                                      gint64                     sync_time)
 {
   ephy_sync_utils_set_passwords_sync_time (sync_time);
 }
@@ -878,8 +879,8 @@ ephy_password_manager_handle_initial_merge (EphyPasswordManager *self,
   const char *remote_password_field;
   guint64 remote_timestamp;
   guint64 local_timestamp;
-  double remote_server_time_modified;
-  double local_server_time_modified;
+  gint64 remote_server_time_modified;
+  gint64 local_server_time_modified;
 
   g_assert (EPHY_IS_PASSWORD_MANAGER (self));
 
@@ -1105,3 +1106,152 @@ ephy_synchronizable_manager_iface_init (EphySynchronizableManagerInterface *ifac
   iface->save = synchronizable_manager_save;
   iface->merge = synchronizable_manager_merge;
 }
+
+typedef struct {
+  EphyPasswordManager *password_manager;
+  const char *origin;
+  const char *target_origin;
+  const char *username;
+  const char *username_field;
+  const char *password_field;
+} PasswordManagerPromiseData;
+
+static void
+js_password_manager_query_finished_cb (GList    *records,
+                                       JSCValue *resolve)
+{
+  JSCContext *js_context;
+  JSCValue *result, *value;
+  EphyPasswordRecord *record;
+
+  record = records && records->data ? EPHY_PASSWORD_RECORD (records->data) : NULL;
+  js_context = jsc_value_get_context (resolve);
+
+  if (record) {
+    JSCValue *property;
+
+    result = jsc_value_new_object (js_context, NULL, NULL);
+
+    property = jsc_value_new_string (js_context, ephy_password_record_get_username (record));
+    jsc_value_object_set_property (result, "username", property);
+    g_object_unref (property);
+
+    property = jsc_value_new_string (js_context, ephy_password_record_get_password (record));
+    jsc_value_object_set_property (result, "password", property);
+    g_object_unref (property);
+  } else {
+    result = jsc_value_new_null (js_context);
+  }
+
+  value = jsc_value_function_call (resolve, JSC_TYPE_VALUE, result, G_TYPE_NONE);
+  g_object_unref (value);
+  g_object_unref (result);
+
+  g_list_free_full (records, g_object_unref);
+  g_object_unref (resolve);
+}
+
+static void
+js_password_manager_query_resolve (JSCValue                   *resolve,
+                                   JSCValue                   *reject,
+                                   PasswordManagerPromiseData *data)
+{
+  ephy_password_manager_query (data->password_manager,
+                               NULL,
+                               data->origin,
+                               data->target_origin,
+                               data->username,
+                               data->username_field,
+                               data->password_field,
+                               (EphyPasswordManagerQueryCallback)js_password_manager_query_finished_cb,
+                               g_object_ref (resolve));
+}
+
+static JSCValue *
+js_password_manager_query (EphyPasswordManager *self,
+                           const char          *origin,
+                           const char          *target_origin,
+                           const char          *username,
+                           const char          *username_field,
+                           const char          *password_field)
+{
+  JSCContext *js_context = jsc_context_get_current ();
+  JSCValue *executor, *promise, *retval;
+  PasswordManagerPromiseData data = { self, origin, target_origin, username, username_field, password_field };
+
+  executor = jsc_value_new_function (js_context, NULL,
+                                     G_CALLBACK (js_password_manager_query_resolve),
+                                     &data, NULL,
+                                     G_TYPE_NONE, 2,
+                                     JSC_TYPE_VALUE,
+                                     JSC_TYPE_VALUE);
+  promise = jsc_context_get_value (js_context, "Promise");
+  retval = jsc_value_constructor_call (promise, JSC_TYPE_VALUE, executor, G_TYPE_NONE);
+  g_object_unref (executor);
+  g_object_unref (promise);
+
+  return retval;
+}
+
+static void
+js_password_manager_save (EphyPasswordManager *self,
+                          const char          *origin,
+                          const char          *target_origin,
+                          const char          *username,
+                          const char          *password,
+                          const char          *username_field,
+                          const char          *password_field,
+                          gboolean             is_new)
+{
+  ephy_password_manager_save (self, origin, target_origin, username, password, username_field, password_field, is_new);
+}
+
+static GPtrArray *
+js_password_manager_cached_users (EphyPasswordManager *self,
+                                  const char          *origin)
+{
+  JSCContext *js_context = jsc_context_get_current ();
+  GPtrArray *retval;
+  GList *cached_users, *l;
+
+  cached_users = ephy_password_manager_get_cached_users (self, origin);
+  retval = g_ptr_array_new_with_free_func (g_object_unref);
+
+  for (l = cached_users; l && l->data; l = g_list_next (l))
+    g_ptr_array_add (retval, jsc_value_new_string (js_context, l->data));
+
+  return retval;
+}
+
+void
+ephy_password_manager_export_to_js_context (EphyPasswordManager *self,
+                                            JSCContext          *js_context,
+                                            JSCValue            *js_namespace)
+{
+  JSCClass *js_class;
+  JSCValue *js_password_manager;
+
+  js_class = jsc_context_register_class (js_context, "PasswordManager", NULL, NULL, NULL);
+  jsc_class_add_method (js_class,
+                        "query",
+                        G_CALLBACK (js_password_manager_query), NULL, NULL,
+                        JSC_TYPE_VALUE, 5,
+                        G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+                        G_TYPE_STRING, G_TYPE_STRING);
+  jsc_class_add_method (js_class,
+                        "save",
+                        G_CALLBACK (js_password_manager_save), NULL, NULL,
+                        G_TYPE_NONE, 7,
+                        G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+                        G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+                        G_TYPE_BOOLEAN);
+  jsc_class_add_method (js_class,
+                        "cachedUsers",
+                        G_CALLBACK (js_password_manager_cached_users), NULL, NULL,
+                        G_TYPE_PTR_ARRAY, 1,
+                        G_TYPE_STRING);
+
+  js_password_manager = jsc_value_new_object (js_context, self, js_class);
+  jsc_value_object_set_property (js_namespace, "passwordManager", js_password_manager);
+  g_object_unref (js_password_manager);
+}
