@@ -1,25 +1,21 @@
-/* vim: set sw=2 ts=2 sts=2 et: */
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
- * ephy-shell-test.c
- * This file is part of Epiphany
+ *  Copyright © 2012 - Igalia S.L.
  *
- * Copyright © 2012 - Igalia S.L.
+ *  This file is part of Epiphany.
  *
- * Epiphany is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * Epiphany is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  Epiphany is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Epiphany; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ *  You should have received a copy of the GNU General Public License
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -27,10 +23,8 @@
 #include "ephy-embed.h"
 #include "ephy-embed-container.h"
 #include "ephy-embed-prefs.h"
-#include "ephy-embed-private.h"
 #include "ephy-embed-utils.h"
 #include "ephy-file-helpers.h"
-#include "ephy-private.h"
 #include "ephy-shell.h"
 #include "ephy-test-utils.h"
 #include "ephy-window.h"
@@ -56,13 +50,13 @@ test_ephy_shell_basic_embeds (void)
 
   /* Embed should be created. */
   embed1 = ephy_shell_new_tab_full
-                  (ephy_shell,
-                   NULL, /* title */
-                   NULL, /* related view */
-                   window,
-                   NULL, /* embed */
-                   EPHY_NEW_TAB_DONT_SHOW_WINDOW, /* flags */
-                   gtk_get_current_event_time ());
+             (ephy_shell,
+             NULL,       /* title */
+             NULL,       /* related view */
+             window,
+             NULL,       /* embed */
+             EPHY_NEW_TAB_DONT_SHOW_WINDOW,       /* flags */
+             gtk_get_current_event_time ());
   g_assert (EPHY_IS_EMBED (embed1));
 
   g_assert (gtk_widget_get_toplevel (GTK_WIDGET (embed1)) == GTK_WIDGET (window));
@@ -73,13 +67,13 @@ test_ephy_shell_basic_embeds (void)
 
   /* Another embed should be created */
   embed2 = ephy_shell_new_tab_full
-                  (ephy_shell,
-                   NULL, /* title */
-                   NULL, /* related view */
-                   window, /* window */
-                   NULL, /* embed */
-                   EPHY_NEW_TAB_DONT_SHOW_WINDOW, /* flags */
-                   gtk_get_current_event_time ());
+             (ephy_shell,
+             NULL,       /* title */
+             NULL,       /* related view */
+             window,       /* window */
+             NULL,       /* embed */
+             EPHY_NEW_TAB_DONT_SHOW_WINDOW,       /* flags */
+             gtk_get_current_event_time ());
   g_assert (EPHY_IS_EMBED (embed2));
 
   /* A second children should exist now. */
@@ -103,8 +97,8 @@ test_ephy_shell_parent_windows (void)
 
   /* parent-window provided */
   embed = ephy_shell_new_tab
-                  (ephy_shell, EPHY_WINDOW (window), NULL,
-                   EPHY_NEW_TAB_DONT_SHOW_WINDOW);
+            (ephy_shell, EPHY_WINDOW (window), NULL,
+            EPHY_NEW_TAB_DONT_SHOW_WINDOW);
 
   g_assert (EPHY_IS_EMBED (embed));
   g_assert (gtk_widget_get_toplevel (GTK_WIDGET (embed)) == window);
@@ -114,8 +108,8 @@ test_ephy_shell_parent_windows (void)
   /* Another new-window */
   window2 = GTK_WIDGET (ephy_window_new ());
   embed = ephy_shell_new_tab
-                  (ephy_shell, EPHY_WINDOW (window2), NULL,
-                   EPHY_NEW_TAB_DONT_SHOW_WINDOW);
+            (ephy_shell, EPHY_WINDOW (window2), NULL,
+            EPHY_NEW_TAB_DONT_SHOW_WINDOW);
 
   /* The parent window should be a completely new one. */
   g_assert (EPHY_IS_EMBED (embed));
@@ -142,8 +136,8 @@ test_ephy_shell_tab_load (void)
 
   /* homepage is "about:blank" for now, see embed/ephy-web-view.c */
   embed = ephy_shell_new_tab
-                  (ephy_shell, EPHY_WINDOW (window), NULL,
-                   EPHY_NEW_TAB_DONT_SHOW_WINDOW);
+            (ephy_shell, EPHY_WINDOW (window), NULL,
+            EPHY_NEW_TAB_DONT_SHOW_WINDOW);
   ephy_web_view_load_homepage (ephy_embed_get_web_view (embed));
 
   g_assert (EPHY_IS_EMBED (embed));
@@ -161,8 +155,8 @@ test_ephy_shell_tab_load (void)
 
   /* open-page "about:epiphany" for testing. */
   embed = ephy_shell_new_tab
-                  (ephy_shell, EPHY_WINDOW (window), NULL,
-                   EPHY_NEW_TAB_DONT_SHOW_WINDOW);
+            (ephy_shell, EPHY_WINDOW (window), NULL,
+            EPHY_NEW_TAB_DONT_SHOW_WINDOW);
   ephy_web_view_load_url (ephy_embed_get_web_view (embed), "about:epiphany");
 
   g_assert (EPHY_IS_EMBED (embed));
@@ -250,7 +244,7 @@ test_ephy_shell_tab_from_external (void)
   loop = ephy_test_utils_setup_ensure_web_views_are_loaded ();
 
   embed = ephy_shell_new_tab (ephy_shell, NULL, NULL, "about:epiphany",
-                               EPHY_NEW_TAB_DONT_SHOW_WINDOW | EPHY_NEW_TAB_OPEN_PAGE);
+                              EPHY_NEW_TAB_DONT_SHOW_WINDOW | EPHY_NEW_TAB_OPEN_PAGE);
   window = gtk_widget_get_toplevel (GTK_WIDGET (embed));
   notebook = ephy_window_get_notebook (EPHY_WINDOW (window));
 
@@ -291,7 +285,7 @@ test_ephy_shell_tab_from_external (void)
   /* This should work */
   ephy_test_utils_check_ephy_embed_address (embed2, "ephy-about:overview");
   g_assert_cmpint (gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)), ==, 1);
-  
+
   loop = ephy_test_utils_setup_wait_until_load_is_committed (ephy_embed_get_web_view (embed2));
 
   embed5 = ephy_shell_new_tab (ephy_shell, EPHY_WINDOW (window), NULL, "about:applications",
@@ -326,7 +320,7 @@ main (int argc, char *argv[])
 
   ephy_debug_init ();
 
-  if (!ephy_file_helpers_init (NULL, EPHY_FILE_HELPERS_PRIVATE_PROFILE | EPHY_FILE_HELPERS_ENSURE_EXISTS, NULL)) {
+  if (!ephy_file_helpers_init (NULL, EPHY_FILE_HELPERS_TESTING_MODE | EPHY_FILE_HELPERS_ENSURE_EXISTS, NULL)) {
     g_debug ("Something wrong happened with ephy_file_helpers_init()");
     return -1;
   }
